"""\
Script based on CMFAudio, CMFEvent, CMFCore, and CMFDefault type stuff.

This file is an installation script for CMFVirtualHost.  It's meant to be used
as an External Method.  To use, add an external method to the root of the CMF
Site that you want CMFVirtualHost registered in with the configuration:

 id: install_virtualhost
 title: Install Virtual Host Tool *optional*
 module name: CMFVirtualHost.Install
 function name: install

Then go to the management screen for the newly added external method
and click the 'Try it' tab.  The install function will execute and give
information about the steps it took to register and install
CMFVirtualHost into the CMF Site instance.
"""
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.utils import getToolByName
from Products.CMFCore import CMFCorePermissions
from Products.CMFVirtualHost import virtualhost_globals, VirtualHostTool
from Acquisition import aq_base
from AccessControl import getSecurityManager
from cStringIO import StringIO
from Products.CMFDefault.Portal import CMFSite
import string

def install(self):
    " Add the CMFVirtualHost and associated necessities "

    container=self
    if not isinstance(container, CMFSite): return "This script can only be run in the root of a CMF site (%s)" % container.getId()


    rootObj=self.getPhysicalRoot()
    if not rootObj.objectItems( "Virtual Host Folder" ): return "The CMFVirtualHostTool requires that the VirtualHostFolder be installed in the Zope root"

    if getToolByName(self, 'portal_virtualhost', None): return "A CMFVirtualHost tool is already installed here"


    if not getSecurityManager().checkPermission(CMFCorePermissions.ManagePortal, container): return "You must have the 'Manage Portal' permission to run this script"

    out = StringIO()
    skinstool = getToolByName(self, 'portal_skins')


    newTool=VirtualHostTool.VirtualHostTool()

    container._setObject(newTool.getId(), newTool)
    out.write("Added portal_virtualhost tool to CMF root\n")

    # Setup the skins
    # This is borrowed from CMFDefault/scripts/addImagesToSkinPaths.pys
    if 'virtualhost' not in skinstool.objectIds() or 'zpt_virtualhost' not in skinstool.objectIds():
        # We need to add Filesystem Directory Views for any directories
        # in our skins/ directory.  These directories should already be
        # configured.
        addDirectoryViews(skinstool, 'skins', virtualhost_globals)
        out.write("Added 'virtualhost' and 'zpt_virtualhost' directory views, as necessary, to portal_skins\n")

    # Now we need to go through the skin configurations and insert
    # 'virtualhost' into the configurations.  In DTML skins, this should be
    # right before where 'content' is placed; if 'content' not found, append
    # it to the beginning.  For ZPT skins, add both 'zpt_virtualhost' and
    # 'virtualhost' before 'zpt_content' ('virtualhost' has the breadcrumbs
    # script that 'zpt_virtualhost' needs, and another zpt skin has another
    # breadcrumbs script, so we need both early on)

    skins = skinstool.getSkinSelections()
    for skin in skins:
        path = skinstool.getSkinPath(skin)
        path = map(string.strip, string.split(path,','))
        changed=[]
        if 'zpt_content' in path:
            if 'zpt_virtualhost' not in path:
                path.insert(path.index('zpt_content'), 'zpt_virtualhost')
                changed.append('zpt_virtualhost')
            if 'virtualhost' not in path:
                path.insert(path.index('zpt_virtualhost')+1, 'virtualhost')
                changed.append('virtualhost')
        elif 'virtualhost' not in path:
            try: path.insert(path.index('content'), 'virtualhost')
            except ValueError:
                path.insert(0,'virtualhost')
            changed.append('virtualhost')
        if changed:
            path = string.join(path, ', ')
            # addSkinSelection will replace existing skins as well.
            skinstool.addSkinSelection(skin, path)
            out.write("Added '%s' to %s skin\n" % (" and ".join(changed),skin))
        else:
            out.write("Skipping %s skin: no changes seem to be needed\n" % (
                skin))

    return out.getvalue()

