
"""VirtualHostTool interface
"""
from Interface import Base
# requires the VirtualHostFolder product to be installed in the Zope root




class IVirtualHostTool (Base):
    """requires the VirtualHostFolder product to be installed in the Zope
    root"""

    def manage_skins(self, manager_skins=[], owner_skins=[], default_skin=None, request=None):
        """provides both a general way for adding skins and a through-the-web
        interface"""

    def getTitle( self, request=None ):
        """ get the host or portal title """

    def getRootURL( self, request=None ):
        """
        Return the host's canonical root URL in regard to entire Zope
        """

    def getActualRootURL( self, request=None ):
        """
        Return the host's actual current root URL in regard to entire Zope
        """

    def getRootPath( self, request=None ):
        """
        Return the host's canonical root path in regard to entire Zope
        """

    def getActualRootPath( self, request=None ):
        """
        Return the host's actual root path in regard to entire Zope
        """
    def getRootObject( self, request = None ):
        """ Return the canonical root object """

    def getActualRootObject( self, request = None ):
        """ Return the actual root object """

    def getProperty( self, attr, request=None ):
        """
        Returns the stored value of the given name, if any, for the current VH (or none).
        """

    def getProperties( self, request=None ):
        """
        Returns a list of property tuples (name, value) for the current VH.
        """

    def getVirtualHostFolder( self ):
        """returns the VHF object, if it can"""

    def getVirtualHost( self, request=None ):
        """returns the current virtual host object, if it can"""

    def getSkinManagerChoices( self, request=None ):
        """gets the skin names approved by the manager for the current host"""

    def setSkinManagerChoices( self, skinNames, request=None, mfunc=None ):
        """sets the manager skin names.  Private because through the web setting
        of this is tricky: we should be checking the permissions on the static
        virtual root, not anywhere else, for all of the skin setters.  NO
        SECURITY CHECKS; PRIVATE.  USE MANGAGE_SKINS INSTEAD UNLESS THIS IS
        NECESSARY."""

    def getSkinOwnerChoices( self, request=None ):
        """gets the skin names approved by the owner for the current host (as
        already limited by the manager)"""

    def setSkinOwnerChoices( self, skinNames, request=None, mfunc=None ):
        """sets the owner skin names.  Private because through the web setting
        of this is tricky: we should be checking the permissions on the static
        virtual root, not anywhere else, for all of the skin setters.  NO
        SECURITY CHECKS; PRIVATE.  USE MANGAGE_SKINS INSTEAD UNLESS THIS IS
        NECESSARY."""

    def getDefaultSkinName( self, request=None ):
        """gets the default skin for the current host"""

    def setDefaultSkinName( self, skinName, request=None, mfunc=None ):
        """sets the default skin.  Private because through the web setting
        of this is tricky: we should be checking the permissions on the static
        virtual root, not anywhere else, for all of the skin setters.  NO
        SECURITY CHECKS; PRIVATE.  USE MANGAGE_SKINS INSTEAD UNLESS THIS IS
        NECESSARY."""

    def getSecurityLevel( self, request=None ):
        """gets the security level of the current user for the static virtual
        root of the current host."""

    def setProperty( self, attr, val, request=None ):
        """
        For host as indicated by hostkey, sets attr to val
        """

    ##def getBreadcrumbs(self, root_name="home", includeQueryString=0, request=None):
    ##    """ list of "id", "url" dicts, derived simply from actual URL passed to
    ##    Zope, without any title"""

    def getOriginalRequestURL(self, request=None):
        """ the path part of the URL as originally entered """

    def getPathToContent(self, obj, request=None):
        """ get the path to an object, taking into account aliases and the
        like """

    def getURLToContent(self, obj, request=None):
        """ get the URL to an object, taking into account aliases and the
        like """

    def getBreadcrumbs(self, obj, include_root=1, root_name='home', ignoreIds=("index_html","talkback"), careful=0, request=None):
        """returns id title and url of each object in acquisition path of obj.
        includes root in breadcrumbs if include_root; names roor root_name;
        does not include entries for objects with ids in ignoreIds; uses a
        heavier-weight process that trades off speed for confident accuracy
        if careful is 1."""

    def getStatus(self, request=None):
        """ get boolean true (virtual host in use in current request) or false
        (nope) """
